summaryrefslogtreecommitdiffstats
path: root/printing/metafile.h
diff options
context:
space:
mode:
Diffstat (limited to 'printing/metafile.h')
-rw-r--r--printing/metafile.h11
1 files changed, 6 insertions, 5 deletions
diff --git a/printing/metafile.h b/printing/metafile.h
index 264c8fe..1142a39 100644
--- a/printing/metafile.h
+++ b/printing/metafile.h
@@ -57,14 +57,15 @@ class Metafile {
// VectorPlatformDevice implementation bound to the context created by
// StartPage or NULL on error.
virtual skia::PlatformDevice* StartPageForVectorCanvas(
- const gfx::Size& page_size, const gfx::Point& content_origin,
+ const gfx::Size& page_size,
+ const gfx::Rect& content_area,
const float& scale_factor) = 0;
// Prepares a context for rendering a new page at the specified
// |content_origin| with the given |page_size| and a |scale_factor| to use for
// the drawing. The units are in points (=1/72 in). Returns true on success.
virtual bool StartPage(const gfx::Size& page_size,
- const gfx::Point& content_origin,
+ const gfx::Rect& content_area,
const float& scale_factor) = 0;
// Closes the current page and destroys the context used in rendering that
@@ -57,14 +57,15 @@ class Metafile {
const float& scale_factor) = 0;
- // Prepares a context for rendering a new page at the specified
- // |content_origin| with the given |page_size| and a |scale_factor| to use for
- // the drawing. The units are in points (=1/72 in). Returns true on success.
+ // Prepares a context for rendering a new page with the given |page_size|,
+ // |content_area| and a |scale_factor| to use for the drawing. The units are
+ // in points (=1/72 in). Returns true on success.
virtual bool StartPage(const gfx::Size& page_size,